import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The ``AWS::SNS::Topic`` resource creates a topic to which notifications can be published.
 *   One account can create a maximum of 100,000 standard topics and 1,000 FIFO topics. For more information, see [endpoints and quotas](https://docs.aws.amazon.com/general/latest/gr/sns.html) in the *General Reference*.
 *    The structure of ``AUTHPARAMS`` depends on the .signature of the API request. For more information, see [Examples of the complete Signature Version 4 signing process](https://docs.aws.amazon.com/general/latest/gr/sigv4-signed-request-examples.html) in the *General Reference*.
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const carSalesTopic = new aws_native.sns.Topic("carSalesTopic", {});
 * const erpIntegrationQueue = new aws_native.sqs.Queue("erpIntegrationQueue", {});
 * const erpSubscription = new aws_native.sns.Subscription("erpSubscription", {
 *     topicArn: carSalesTopic.id,
 *     endpoint: erpIntegrationQueue.arn,
 *     protocol: "sqs",
 *     rawMessageDelivery: true,
 * });
 * const crmIntegrationQueue = new aws_native.sqs.Queue("crmIntegrationQueue", {});
 * const crmSubscription = new aws_native.sns.Subscription("crmSubscription", {
 *     topicArn: carSalesTopic.id,
 *     endpoint: crmIntegrationQueue.arn,
 *     protocol: "sqs",
 *     rawMessageDelivery: true,
 *     filterPolicy: {
 *         "buyer-class": ["vip"],
 *     },
 * });
 * const config = new pulumi.Config();
 * const myHttpEndpoint = config.require("myHttpEndpoint");
 * const scmSubscription = new aws_native.sns.Subscription("scmSubscription", {
 *     topicArn: carSalesTopic.id,
 *     endpoint: myHttpEndpoint,
 *     protocol: "https",
 *     deliveryPolicy: {
 *         healthyRetryPolicy: {
 *             numRetries: 20,
 *             minDelayTarget: 10,
 *             maxDelayTarget: 30,
 *             numMinDelayRetries: 3,
 *             numMaxDelayRetries: 17,
 *             numNoDelayRetries: 0,
 *             backoffFunction: "exponential",
 *         },
 *     },
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const carSalesTopic = new aws_native.sns.Topic("carSalesTopic", {});
 * const erpIntegrationQueue = new aws_native.sqs.Queue("erpIntegrationQueue", {});
 * const erpSubscription = new aws_native.sns.Subscription("erpSubscription", {
 *     topicArn: carSalesTopic.id,
 *     endpoint: erpIntegrationQueue.arn,
 *     protocol: "sqs",
 *     rawMessageDelivery: true,
 * });
 * const crmIntegrationQueue = new aws_native.sqs.Queue("crmIntegrationQueue", {});
 * const crmSubscription = new aws_native.sns.Subscription("crmSubscription", {
 *     topicArn: carSalesTopic.id,
 *     endpoint: crmIntegrationQueue.arn,
 *     protocol: "sqs",
 *     rawMessageDelivery: true,
 *     filterPolicy: {
 *         "buyer-class": ["vip"],
 *     },
 * });
 * const config = new pulumi.Config();
 * const myHttpEndpoint = config.require("myHttpEndpoint");
 * const scmSubscription = new aws_native.sns.Subscription("scmSubscription", {
 *     topicArn: carSalesTopic.id,
 *     endpoint: myHttpEndpoint,
 *     protocol: "https",
 *     deliveryPolicy: {
 *         healthyRetryPolicy: {
 *             numRetries: 20,
 *             minDelayTarget: 10,
 *             maxDelayTarget: 30,
 *             numMinDelayRetries: 3,
 *             numMaxDelayRetries: 17,
 *             numNoDelayRetries: 0,
 *             backoffFunction: "exponential",
 *         },
 *     },
 * });
 *
 * ```
 */
export declare class Topic extends pulumi.CustomResource {
    /**
     * Get an existing Topic resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Topic;
    /**
     * Returns true if the given object is an instance of Topic.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Topic;
    /**
     * The archive policy determines the number of days SNS retains messages. You can set a retention period from 1 to 365 days.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SNS::Topic` for more information about the expected schema for this property.
     */
    readonly archivePolicy: pulumi.Output<any | undefined>;
    /**
     * Enables content-based deduplication for FIFO topics.
     *   +  By default, ``ContentBasedDeduplication`` is set to ``false``. If you create a FIFO topic and this attribute is ``false``, you must specify a value for the ``MessageDeduplicationId`` parameter for the [Publish](https://docs.aws.amazon.com/sns/latest/api/API_Publish.html) action.
     *   +  When you set ``ContentBasedDeduplication`` to ``true``, SNS uses a SHA-256 hash to generate the ``MessageDeduplicationId`` using the body of the message (but not the attributes of the message).
     *  (Optional) To override the generated value, you can specify a value for the the ``MessageDeduplicationId`` parameter for the ``Publish`` action.
     */
    readonly contentBasedDeduplication: pulumi.Output<boolean | undefined>;
    /**
     * The body of the policy document you want to use for this topic.
     *  You can only add one policy per topic.
     *  The policy must be in JSON string format.
     *  Length Constraints: Maximum length of 30,720.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SNS::Topic` for more information about the expected schema for this property.
     */
    readonly dataProtectionPolicy: pulumi.Output<any | undefined>;
    /**
     * The ``DeliveryStatusLogging`` configuration enables you to log the delivery status of messages sent from your Amazon SNS topic to subscribed endpoints with the following supported delivery protocols:
     *   +  HTTP
     *   +  Amazon Kinesis Data Firehose
     *   +   AWS Lambda
     *   +  Platform application endpoint
     *   +  Amazon Simple Queue Service
     *
     *  Once configured, log entries are sent to Amazon CloudWatch Logs.
     */
    readonly deliveryStatusLogging: pulumi.Output<outputs.sns.TopicLoggingConfig[] | undefined>;
    /**
     * The display name to use for an SNS topic with SMS subscriptions. The display name must be maximum 100 characters long, including hyphens (-), underscores (_), spaces, and tabs.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * Specifies the throughput quota and deduplication behavior to apply for the FIFO topic. Valid values are `Topic` or `MessageGroup` .
     */
    readonly fifoThroughputScope: pulumi.Output<string | undefined>;
    /**
     * Set to true to create a FIFO topic.
     */
    readonly fifoTopic: pulumi.Output<boolean | undefined>;
    /**
     * The ID of an AWS managed customer master key (CMK) for SNS or a custom CMK. For more information, see [Key terms](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html#sse-key-terms). For more examples, see ``KeyId`` in the *API Reference*.
     *  This property applies only to [server-side-encryption](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html).
     */
    readonly kmsMasterKeyId: pulumi.Output<string | undefined>;
    /**
     * The signature version corresponds to the hashing algorithm used while creating the signature of the notifications, subscription confirmations, or unsubscribe confirmation messages sent by Amazon SNS. By default, ``SignatureVersion`` is set to ``1``.
     */
    readonly signatureVersion: pulumi.Output<string | undefined>;
    /**
     * The SNS subscriptions (endpoints) for this topic.
     *   If you specify the ``Subscription`` property in the ``AWS::SNS::Topic`` resource and it creates an associated subscription resource, the associated subscription is not deleted when the ``AWS::SNS::Topic`` resource is deleted.
     */
    readonly subscription: pulumi.Output<outputs.sns.TopicSubscription[] | undefined>;
    /**
     * The list of tags to add to a new topic.
     *   To be able to tag a topic on creation, you must have the ``sns:CreateTopic`` and ``sns:TagResource`` permissions.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Returns the ARN of an Amazon SNS topic.
     */
    readonly topicArn: pulumi.Output<string>;
    /**
     * The name of the topic you want to create. Topic names must include only uppercase and lowercase ASCII letters, numbers, underscores, and hyphens, and must be between 1 and 256 characters long. FIFO topic names must end with ``.fifo``.
     *  If you don't specify a name, CFN generates a unique physical ID and uses that ID for the topic name. For more information, see [Name type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-name.html).
     *   If you specify a name, you can't perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
     */
    readonly topicName: pulumi.Output<string | undefined>;
    /**
     * Tracing mode of an SNS topic. By default ``TracingConfig`` is set to ``PassThrough``, and the topic passes through the tracing header it receives from an SNS publisher to its subscriptions. If set to ``Active``, SNS will vend X-Ray segment data to topic owner account if the sampled flag in the tracing header is true.
     */
    readonly tracingConfig: pulumi.Output<string | undefined>;
    /**
     * Create a Topic resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TopicArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Topic resource.
 */
export interface TopicArgs {
    /**
     * The archive policy determines the number of days SNS retains messages. You can set a retention period from 1 to 365 days.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SNS::Topic` for more information about the expected schema for this property.
     */
    archivePolicy?: any;
    /**
     * Enables content-based deduplication for FIFO topics.
     *   +  By default, ``ContentBasedDeduplication`` is set to ``false``. If you create a FIFO topic and this attribute is ``false``, you must specify a value for the ``MessageDeduplicationId`` parameter for the [Publish](https://docs.aws.amazon.com/sns/latest/api/API_Publish.html) action.
     *   +  When you set ``ContentBasedDeduplication`` to ``true``, SNS uses a SHA-256 hash to generate the ``MessageDeduplicationId`` using the body of the message (but not the attributes of the message).
     *  (Optional) To override the generated value, you can specify a value for the the ``MessageDeduplicationId`` parameter for the ``Publish`` action.
     */
    contentBasedDeduplication?: pulumi.Input<boolean>;
    /**
     * The body of the policy document you want to use for this topic.
     *  You can only add one policy per topic.
     *  The policy must be in JSON string format.
     *  Length Constraints: Maximum length of 30,720.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SNS::Topic` for more information about the expected schema for this property.
     */
    dataProtectionPolicy?: any;
    /**
     * The ``DeliveryStatusLogging`` configuration enables you to log the delivery status of messages sent from your Amazon SNS topic to subscribed endpoints with the following supported delivery protocols:
     *   +  HTTP
     *   +  Amazon Kinesis Data Firehose
     *   +   AWS Lambda
     *   +  Platform application endpoint
     *   +  Amazon Simple Queue Service
     *
     *  Once configured, log entries are sent to Amazon CloudWatch Logs.
     */
    deliveryStatusLogging?: pulumi.Input<pulumi.Input<inputs.sns.TopicLoggingConfigArgs>[]>;
    /**
     * The display name to use for an SNS topic with SMS subscriptions. The display name must be maximum 100 characters long, including hyphens (-), underscores (_), spaces, and tabs.
     */
    displayName?: pulumi.Input<string>;
    /**
     * Specifies the throughput quota and deduplication behavior to apply for the FIFO topic. Valid values are `Topic` or `MessageGroup` .
     */
    fifoThroughputScope?: pulumi.Input<string>;
    /**
     * Set to true to create a FIFO topic.
     */
    fifoTopic?: pulumi.Input<boolean>;
    /**
     * The ID of an AWS managed customer master key (CMK) for SNS or a custom CMK. For more information, see [Key terms](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html#sse-key-terms). For more examples, see ``KeyId`` in the *API Reference*.
     *  This property applies only to [server-side-encryption](https://docs.aws.amazon.com/sns/latest/dg/sns-server-side-encryption.html).
     */
    kmsMasterKeyId?: pulumi.Input<string>;
    /**
     * The signature version corresponds to the hashing algorithm used while creating the signature of the notifications, subscription confirmations, or unsubscribe confirmation messages sent by Amazon SNS. By default, ``SignatureVersion`` is set to ``1``.
     */
    signatureVersion?: pulumi.Input<string>;
    /**
     * The SNS subscriptions (endpoints) for this topic.
     *   If you specify the ``Subscription`` property in the ``AWS::SNS::Topic`` resource and it creates an associated subscription resource, the associated subscription is not deleted when the ``AWS::SNS::Topic`` resource is deleted.
     */
    subscription?: pulumi.Input<pulumi.Input<inputs.sns.TopicSubscriptionArgs>[]>;
    /**
     * The list of tags to add to a new topic.
     *   To be able to tag a topic on creation, you must have the ``sns:CreateTopic`` and ``sns:TagResource`` permissions.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The name of the topic you want to create. Topic names must include only uppercase and lowercase ASCII letters, numbers, underscores, and hyphens, and must be between 1 and 256 characters long. FIFO topic names must end with ``.fifo``.
     *  If you don't specify a name, CFN generates a unique physical ID and uses that ID for the topic name. For more information, see [Name type](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-name.html).
     *   If you specify a name, you can't perform updates that require replacement of this resource. You can perform updates that require no or some interruption. If you must replace the resource, specify a new name.
     */
    topicName?: pulumi.Input<string>;
    /**
     * Tracing mode of an SNS topic. By default ``TracingConfig`` is set to ``PassThrough``, and the topic passes through the tracing header it receives from an SNS publisher to its subscriptions. If set to ``Active``, SNS will vend X-Ray segment data to topic owner account if the sampled flag in the tracing header is true.
     */
    tracingConfig?: pulumi.Input<string>;
}
